pub struct TextEncodeSettings {
pub extra_float_digits: i32,
}Expand description
Session settings that affect how values are encoded as text.
PostgreSQL’s text output for some types depends on session state. Encoders
whose output must not depend on the session, such as everything evaluated
in the dataflow layer, use TextEncodeSettings::STABLE.
Fields
extra_float_digits: i32PostgreSQL’s extra_float_digits: positive values select the shortest
round-trippable encoding for float4 and float8, while zero and
negative values limit output to FLOAT4_DIGITS or FLOAT8_DIGITS plus
this value significant digits.
Implementations
Sourceimpl TextEncodeSettings
impl TextEncodeSettings
Sourcepub const STABLE: TextEncodeSettings
pub const STABLE: TextEncodeSettings
Settings that do not depend on session state.